@@ -1,6 +1,6 @@
 from fastadmin.app import admin_app
 from fastadmin.models.base import ModelAdmin
-from fastadmin.models.decorators import register
+from fastadmin.models.decorators import action, display, register
 from fastadmin.models.orm.tortoise import TortoiseModelAdmin
 from fastadmin.schemas.api import ExportFormat
 from fastadmin.schemas.configuration import WidgetType
